summaryrefslogtreecommitdiffstats
path: root/korn/tdeio_proto.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/tdeio_proto.h')
-rw-r--r--korn/tdeio_proto.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/korn/tdeio_proto.h b/korn/tdeio_proto.h
index 67e673e74..384097683 100644
--- a/korn/tdeio_proto.h
+++ b/korn/tdeio_proto.h
@@ -16,11 +16,11 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
-#ifndef MK_KIO_PROTO_H
-#define MK_KIO_PROTO_H
+#ifndef MK_TDEIO_PROTO_H
+#define MK_TDEIO_PROTO_H
/*
* KIO can handle multiple protocols. But some protocols have their own
* manipulations of KURL or MetaData , and some protocols could do more then other
* protocols. So, this class is the generic class of a class specified
* by a protocol.
@@ -32,20 +32,20 @@ class TQString;
#include <tqstringlist.h>
#include "protocol.h"
-#include "kio.h"
+#include "tdeio.h"
-class KIO_Protocol : public Protocol
+class TDEIO_Protocol : public Protocol
{
public:
/*
* Constuctor; empty
*/
- KIO_Protocol() {}
+ TDEIO_Protocol() {}
/*
* Destructor; empty too
*/
- virtual ~KIO_Protocol() {}
+ virtual ~TDEIO_Protocol() {}
/*
* Public enumeration
@@ -139,7 +139,7 @@ public:
virtual void readMailKURL ( KURL &, TDEIO::MetaData & ) const { }
- virtual const KIO_Protocol* getKIOProtocol() const { return this; }
+ virtual const TDEIO_Protocol* getKIOProtocol() const { return this; }
virtual void readEntries( TQMap< TQString, TQString >* ) const;
virtual void readEntries( TQMap< TQString, TQString >*, TQMap< TQString, TQString >* ) const = 0;
@@ -154,4 +154,4 @@ protected:
void clearFields( TQMap< TQString, TQString > *map, const Fields fields ) const;
};
-#endif //MK_KIO_PROTO_H
+#endif //MK_TDEIO_PROTO_H
@@ -16,11 +16,11 @@
/*
- * KIO can handle multiple protocols. But some protocols have their own
+ * TDEIO can handle multiple protocols. But some protocols have their own
* manipulations of KURL or MetaData , and some protocols could do more then other
* protocols. So, this class is the generic class of a class specified